==> cockpit-ovirt-0.11.36.tar.gz: cockpit-ovirt-0.11.36/dashboard/src/components/common/Selectbox.js <==
import React from 'react'

const Selectbox = ({optionList, selectedOption = null, callBack, gdeployWizardType = "none"}) => {
    const options = [];
    let selected = selectedOption;
    if (selected === null) {
        selected = optionList[0];
    }
    optionList.forEach(function (option, index) {
        if(gdeployWizardType === "create_volume") {
          options.push(
              <li value={option.key} key={option.key}
                  onClick={() => callBack(option.key)}>
                  <textarea rows="1" cols="50" id="textArea" type="submit"
                  onKeyDown={() => {
                    if(event.code === "Enter" || event.code === "Tab") {
                      callBack(document.getElementById("textArea").value)
                    }
                  }}
                  onBlur={() => callBack(document.getElementById("textArea").value)}>
                    {option.key}
                  </textarea>
              </li>
          );
        } else {
          if(option.title !== null && option.title.length > 0) {
            options.push(
                <li value={option.key} key={option.key}
                    onClick={() => callBack(option.key)}>
                    <a>
                      {option.title}
                    </a>
                </li>
            );
          }
        }
        if (option.key === selectedOption) {
            selected = option
        }
    }, this);
    return (
      <div className="btn-group bootstrap-select dropdown form-control">
          <button className="btn btn-default dropdown-toggle selectbox-option" type="button"
              data-toggle="dropdown" aria-expanded="false">
              <span className="pull-left selectbox-text">{selected.title}</span>
              <span className="caret" />
          </button>
          <ul className="dropdown-menu">{options}</ul>
      </div>
    )
};

export default Selectbox

==> cockpit-ovirt-0.12.4.tar.gz: cockpit-ovirt-0.12.4/dashboard/src/components/common/Selectbox.js <==
import React from 'react'

const Selectbox = ({optionList, selectedOption = null, callBack, ansibleWizardType = "none"}) => {
    const options = [];
    let selected = selectedOption;
    if (selected === null) {
        selected = optionList[0];
    }
    optionList.forEach(function (option, index) {
        if(ansibleWizardType === "create_volume") {
          options.push(
              <li value={option.key} key={option.key}
                  onClick={() => callBack(option.key)}>
                  <textarea rows="1" cols="50" id="textArea" type="submit"
                  onKeyDown={() => {
                    if(event.code === "Enter" || event.code === "Tab") {
                      callBack(document.getElementById("textArea").value)
                    }
                  }}
                  onBlur={() => callBack(document.getElementById("textArea").value)}>
                    {option.key}
                  </textarea>
              </li>
          );
        } else {
          if(option.title !== null && option.title.length > 0) {
            options.push(
                <li value={option.key} key={option.key}
                    onClick={() => callBack(option.key)}>
                    <a>
                      {option.title}
                    </a>
                </li>
            );
          }
        }
        if (option.key === selectedOption) {
            selected = option
        }
    }, this);
    return (
      <div className="btn-group bootstrap-select dropdown form-control">
          <button className="btn btn-default dropdown-toggle selectbox-option" type="button"
              data-toggle="dropdown" aria-expanded="false">
              <span className="pull-left selectbox-text">{selected.title}</span>
              <span className="caret" />
          </button>
          <ul className="dropdown-menu">{options}</ul>
      </div>
    )
};

export default Selectbox
